@@ -3,4 +3,7 @@
 Allows you to maintain all the necessary cruft for packaging and building projects separate from
 the code you intentionally write. Built on-top of, and fully compatible with, CookieCutter.
 """
+from cruft._commands import check, create, link, update
 from cruft._version import __version__
+
+__all__ = ["create", "check", "update", "link", "__version__"]
